<div align="center">
    <a href="https://www.weavel.ai">
        <img src="https://i.imgur.com/uQ7ulX3.png" title="Logo" style="" />
    </a>
    <h1>Promptfile</h1>
    <h3>Language support for <code>.prompt</code> files</h3>
    <div>
        <a href="https://pypi.org/project/promptfile" target="_blank">
            <img src="https://img.shields.io/pypi/v/promptfile.svg" alt="PyPI Version"/>
        </a>
    </div>
</div>

## Installation

```bash
pip install promptfile
```
